@@ -1,12 +1,10 @@
-import sys
 import yaml
 import importlib.util
 from .problem import Problem, SingleMethodProblem, MultiMethodProblem
 
 
-def load_problem(yaml_path: str) -> Problem:
-    with open(yaml_path) as f:
-        cfg = yaml.safe_load(f)
+def load_problem(yaml_raw: str) -> Problem:
+    cfg = yaml.safe_load(yaml_raw)
 
     test_cases = cfg.pop("tests", [])
     assert len(cfg) == 1, "too many classes"
@@ -17,11 +15,9 @@ def load_problem(yaml_path: str) -> Problem:
         return MultiMethodProblem(class_name, methods, test_cases)
 
 
-def load_module(py_path: str, module_name: str = "solution"):
-    spec = importlib.util.spec_from_file_location(module_name, py_path)
-    assert spec is not None, "cannot load module"
+def load_module(py_raw: str, module_name: str = "solution"):
+    spec = importlib.util.spec_from_loader(module_name, loader=None)
     module = importlib.util.module_from_spec(spec)
-    sys.modules[module_name] = module
-    assert spec.loader is not None, "cannot get loader"
-    spec.loader.exec_module(module)
+    # exec is dangerous, but it does not run on my computer
+    exec(py_raw, module.__dict__)
     return module
